@@ -18,6 +18,7 @@ from registry import *
 Registry = Registry()
 
 from constants import *
+from editabletext import *
 from role import *
 from state import *
 from text import *
@@ -33,6 +34,18 @@ def Accessible_getitem(self, i):
 		raise IndexError
 	return self.get_child_at_index(i)
 
+def Accessible_str(self):
+        '''
+        Gets a human readable representation of the accessible.
+        
+        @return: Role and name information for the accessible
+        @rtype: string
+        '''
+        try:
+                return '[%s | %s]' % (self.getRoleName(), self.name)
+        except Exception:
+                return '[DEAD]'
+        
 def pointToList(point):
 	return (point.x, point.y)
 
@@ -91,6 +104,40 @@ def hashToAttributeList(h):
 def getEventType(event):
 	return EventType(event.rawType)
 
+def DeviceEvent_str(self):
+        '''
+        Builds a human readable representation of the event.
+
+        @return: Event description
+        @rtype: string
+        '''
+        if self.type == KEY_PRESSED_EVENT:
+            kind = 'pressed'
+        elif self.type == KEY_RELEASED_EVENT:
+            kind = 'released'
+        return '''\
+%s
+\thw_code: %d
+\tevent_string: %s
+\tmodifiers: %d
+\tid: %d
+\ttimestamp: %d
+\tis_text: %s''' % (kind, self.hw_code, self.event_string, self.modifiers,
+                        self.id, self.timestamp, self.is_text)
+
+def Event_str(self):
+        '''
+        Builds a human readable representation of the event including event type,
+        parameters, and source info.
+
+        @return: Event description
+        @rtype: string
+        '''
+        return '%s(%s, %s, %s)\n\tsource: %s\n\thost_application: %s' % \
+               (self.type, self.detail1, self.detail2, self.any_data,
+                self.source, self.host_application)
+  
+
 ### Accessible ###
 Accessible = Atspi.Accessible
 Atspi.Accessible.getChildAtIndex = Atspi.Accessible.get_child_at_index
@@ -99,6 +146,7 @@ Atspi.Accessible.getApplication = Atspi.Accessible.get_application
 Atspi.Accessible.__getitem__ = Accessible_getitem
 Atspi.Accessible.__len__ = Atspi.Accessible.get_child_count
 Atspi.Accessible.__nonzero__ = lambda x: True
+Atspi.Accessible.__str__ = Accessible_str
 Atspi.Accessible.childCount = property(fget=Atspi.Accessible.get_child_count)
 Atspi.Accessible.getChildCount = Atspi.Accessible.get_child_count
 Atspi.Accessible.getIndexInParent = Atspi.Accessible.get_index_in_parent
@@ -174,14 +222,7 @@ Atspi.Component.setSize = Atspi.Component.set_size
 Atspi.Accessible.queryDocument = lambda x: Document(getInterface(Atspi.Accessible.get_document, x))
 
 ### editable text ###
-EditableText = Atspi.EditableText
-Atspi.Accessible.queryEditableText = lambda x: getInterface(Atspi.Accessible.get_editable_text, x)
-Atspi.EditableText.copyText = Atspi.EditableText.copy_text
-Atspi.EditableText.cutText = Atspi.EditableText.cut_text
-Atspi.EditableText.deleteText = Atspi.EditableText.delete_text
-Atspi.EditableText.insertText = Atspi.EditableText.insert_text
-Atspi.EditableText.pasteText = Atspi.EditableText.paste_text
-Atspi.EditableText.setTextContents = Atspi.EditableText.set_text_contents
+Atspi.Accessible.queryEditableText = lambda x: EditableText(getInterface(Atspi.Accessible.get_text, x))
 
 ### hyperlink ###
 Hyperlink = Atspi.Hyperlink
@@ -211,8 +252,8 @@ Atspi.Image.imageLocale = property(fget=Atspi.Image.get_image_locale)
 
 ### selection ###
 Selection = Atspi.Selection
-Atspi.Accessible.querySelection = lambda x: getInterface(Atspi.Accessible.get_selection)
-Atspi.Selection.clearSelectio = Atspi.Selection.clear_selection
+Atspi.Accessible.querySelection = lambda x: getInterface(Atspi.Accessible.get_selection, x)
+Atspi.Selection.clearSelection = Atspi.Selection.clear_selection
 Atspi.Selection.deselectChild = Atspi.Selection.deselect_child
 Atspi.Selection.deselectSelectedChild = Atspi.Selection.deselect_selected_child
 Atspi.Selection.getSelectedChild = Atspi.Selection.get_selected_child
@@ -273,12 +314,16 @@ Atspi.Value.maximumValue = property(fget=Atspi.Value.get_maximum_value)
 Atspi.Value.minimumIncrement = property(fget=Atspi.Value.get_minimum_increment)
 Atspi.Value.minimumValue = property(fget=Atspi.Value.get_minimum_value)
 
+### DeviceEvent ###
+Atspi.DeviceEvent.__str__ = DeviceEvent_str
+
 ### event ###
 Atspi.Event.host_application = property(fget=lambda x: x.source.get_application())
 Atspi.Event.rawType = Atspi.Event.type
 Atspi.Event.source_name = property(fget=lambda x: x.source.name)
 Atspi.Event.source_role = property(fget=lambda x: x.source.getRole())
 Atspi.Event.type = property(fget=getEventType)
+Atspi.Event.__str__ = Event_str
 
 ### RelationSet ###
 Atspi.Relation.getRelationType = Atspi.Relation.get_relation_type
